Class: Multiwoven::Integrations::Core::DestinationConnector
- Inherits:
-
BaseConnector
- Object
- BaseConnector
- Multiwoven::Integrations::Core::DestinationConnector
- Includes:
- RateLimiter
- Defined in:
- lib/multiwoven/integrations/core/destination_connector.rb
Constant Summary
Constants included from Constants
Constants::CATALOG_SPEC_PATH, Constants::CONNECTOR_SPEC_PATH, Constants::DATABRICKS_DRIVER_PATH, Constants::DATABRICKS_MAC_DRIVER_PATH, Constants::FACEBOOK_AUDIENCE_GET_ALL_ACCOUNTS, Constants::HTTP_DELETE, Constants::HTTP_GET, Constants::HTTP_POST, Constants::HTTP_PUT, Constants::INTEGRATIONS_PATH, Constants::KLAVIYO_AUTH_ENDPOINT, Constants::KLAVIYO_AUTH_PAYLOAD, Constants::MAIN_BRANCH_SHA, Constants::META_DATA_PATH, Constants::SNOWFLAKE_DRIVER_PATH, Constants::SNOWFLAKE_MAC_DRIVER_PATH
Constants included from Protocol
Protocol::ConnectionStatusType, Protocol::ConnectorType, Protocol::ControlMessageType, Protocol::DestinationSyncMode, Protocol::LogLevel, Protocol::ModelQueryType, Protocol::MultiwovenMessageType, Protocol::RequestRateLimitingUnit, Protocol::StreamAction, Protocol::StreamType, Protocol::SyncMode, Protocol::SyncStatus
Instance Method Summary collapse
-
#write(_sync_config, _records, _action = "insert") ⇒ Object
Records are transformed json payload send it to the destination SyncConfig is the Protocol::SyncConfig object.
Methods inherited from BaseConnector
#check_connection, #connector_spec, #discover, #meta_data, #relative_path
Methods included from Utils
#build_catalog, #build_stream, #convert_to_json_schema, #create_log_message, #extract_data, #handle_exception, #keys_to_symbols, #logger, #map_type_to_json_schema, #success?
Instance Method Details
#write(_sync_config, _records, _action = "insert") ⇒ Object
Records are transformed json payload send it to the destination SyncConfig is the Protocol::SyncConfig object
10 11 12 13 |
# File 'lib/multiwoven/integrations/core/destination_connector.rb', line 10 def write(_sync_config, _records, _action = "insert") raise "Not implemented" # return Protocol::TrackingMessage end |