Class: Multiwoven::Integrations::Destination::Slack::Client

Inherits:
DestinationConnector
  • Object
show all
Defined in:
lib/multiwoven/integrations/destination/slack/client.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Instance Attribute Details

#channel_idObject

Returns the value of attribute channel_id.



10
11
12
# File 'lib/multiwoven/integrations/destination/slack/client.rb', line 10

def channel_id
  @channel_id
end

Instance Method Details

#check_connection(connection_config) ⇒ Object



12
13
14
15
16
17
18
19
# File 'lib/multiwoven/integrations/destination/slack/client.rb', line 12

def check_connection(connection_config)
  configure_slack(connection_config[:api_token])
  client = ::Slack::Web::Client.new
  client.auth_test
  success_status
rescue StandardError => e
  failure_status(e)
end

#discover(_connection_config = nil) ⇒ Object



21
22
23
24
25
26
# File 'lib/multiwoven/integrations/destination/slack/client.rb', line 21

def discover(_connection_config = nil)
  catalog = build_catalog(load_catalog_streams)
  catalog.to_multiwoven_message
rescue StandardError => e
  handle_exception("SLACK:DISCOVER:EXCEPTION", "error", e)
end

#write(sync_config, records, action = "create") ⇒ Object



28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/multiwoven/integrations/destination/slack/client.rb', line 28

def write(sync_config, records, action = "create")
  # Currently as we only create a message for each record in slack, we are not using actions.
  # This will be changed in future.

  @action = sync_config.stream.action || action
  connection_config = sync_config.destination.connection_specification.with_indifferent_access
  configure_slack(connection_config[:api_token])
  @client = ::Slack::Web::Client.new
  @channel_id = connection_config[:channel_id]
  process_records(records, sync_config.stream)
rescue StandardError => e
  handle_exception("SLACK:WRITE:EXCEPTION", "error", e)
end